get_utterances: Get utterances

View source: R/get.R

get_utterancesR Documentation

Get utterances

Description

Get utterances

Usage

get_utterances(
  collection = NULL,
  language = NULL,
  corpus = NULL,
  role = NULL,
  role_exclude = NULL,
  age = NULL,
  sex = NULL,
  target_child = NULL,
  connection = NULL,
  db_version = "current",
  db_args = NULL
)

Arguments

collection

A character vector of one or more names of collections

language

A character vector of one or more languages

corpus

A character vector of one or more names of corpora

role

A character vector of one or more roles to include

role_exclude

A character vector of one or more roles to exclude

age

A numeric vector of an single age value or a min age value and max age value (inclusive) in months. For a single age value, participants are returned for which that age is within their age range; for two ages, participants are returned for whose age overlaps with the interval between those two ages.

sex

A character vector of values "male" and/or "female"

target_child

A character vector of one or more names of children

connection

Deprecated, ignored (childesr now reads from the childes-db dataset on Redivis)

db_version

String of the name of database version to use

db_args

Deprecated, ignored

Value

A 'tbl' of Utterance data, filtered down by supplied arguments

Identifiers

Numeric ids in childes-db ('transcript_id', 'utterance_id', token 'id', and so on) are internal to a database release: they are not stable across versions of childes-db and should never be used to link data across releases. The TalkBank persistent identifier (the 'pid' column returned by 'get_transcripts()') is the stable, externally-facing identifier for a transcript; use it to match transcripts across database versions or with other TalkBank tools. For reproducible analyses, pin the database version with the 'db_version' argument.

Examples

## Not run: 
get_utterances(target_child = "Shem")

## End(Not run)

childesr documentation built on Sept. 16, 2026, 9:09 a.m.