| get_db_info | R Documentation |
Retrieves hosted information about available versions of childes-db and their corresponding versions of the childes-db dataset on Redivis. If the hosted information cannot be retrieved or does not specify the Redivis version mapping, a mapping built into the package is used instead.
get_db_info()
List of database info, including 'redivis_current' (the childes-db version that is the current Redivis release) and 'redivis_versions' (a named vector mapping childes-db versions to Redivis dataset versions).
## Not run:
get_db_info()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.